@@ -1,5 +1,6 @@
-import os
 import json
+import os
+
 import requests
 
 
@@ -20,12 +21,13 @@ class _SdcCommon(object):
     def __init__(self, token="", sdc_url='https://app.sysdigcloud.com', ssl_verify=True, custom_headers=None):
         self.token = os.environ.get("SDC_TOKEN", token)
         self.hdrs = self.__get_headers(custom_headers)
-        self.url = os.environ.get("SDC_URL", sdc_url)
+        self.url = os.environ.get("SDC_URL", sdc_url).rstrip('/')
         self.ssl_verify = os.environ.get("SDC_SSL_VERIFY", None)
         if self.ssl_verify == None:
             self.ssl_verify = ssl_verify
         else:
-            self.ssl_verify = self.ssl_verify.lower() == 'true'
+            if self.ssl_verify.lower() in ['true', 'false']:
+                self.ssl_verify = self.ssl_verify.lower() == 'true'
 
     def __get_headers(self, custom_headers):
         headers = {
@@ -37,7 +39,7 @@ class _SdcCommon(object):
         return headers
 
     def _checkResponse(self, res):
-        if res.status_code >= 300:
+        if res.status_code >= 300:  # FIXME: Should it be >=400? 301 = Moved Permanently, 302 = Found, 303 = See Other
             errorcode = res.status_code
             self.lasterr = None
 
@@ -225,7 +227,8 @@ class _SdcCommon(object):
             }
         }
 
-        res = requests.post(self.url + '/api/notificationChannels', headers=self.hdrs, data=json.dumps(channel_json), verify=self.ssl_verify)
+        res = requests.post(self.url + '/api/notificationChannels', headers=self.hdrs, data=json.dumps(channel_json),
+                            verify=self.ssl_verify)
         return self._request_result(res)
 
     def create_notification_channel(self, channel):
@@ -253,14 +256,16 @@ class _SdcCommon(object):
         if 'id' not in channel:
             return [False, "Invalid channel format"]
 
-        res = requests.put(self.url + '/api/notificationChannels/' + str(channel['id']), headers=self.hdrs, data=json.dumps({"notificationChannel": channel}), verify=self.ssl_verify)
+        res = requests.put(self.url + '/api/notificationChannels/' + str(channel['id']), headers=self.hdrs,
+                           data=json.dumps({"notificationChannel": channel}), verify=self.ssl_verify)
         return self._request_result(res)
 
     def delete_notification_channel(self, channel):
         if 'id' not in channel:
             return [False, "Invalid channel format"]
 
-        res = requests.delete(self.url + '/api/notificationChannels/' + str(channel['id']), headers=self.hdrs, verify=self.ssl_verify)
+        res = requests.delete(self.url + '/api/notificationChannels/' + str(channel['id']), headers=self.hdrs,
+                              verify=self.ssl_verify)
         if not self._checkResponse(res):
             return False, self.lasterr
         return True, None
@@ -357,84 +362,6 @@ class _SdcCommon(object):
                             data=json.dumps(req_json), verify=self.ssl_verify)
         return self._request_result(res)
 
-    def post_event(self, name, description=None, severity=None, event_filter=None, tags=None):
-        '''**Description**
-            Send an event to Sysdig Monitor. The events you post are available in the Events tab in the Sysdig Monitor UI and can be overlied to charts.
-
-        **Arguments**
-            - **name**: the name of the new event.
-            - **description**: a longer description offering detailed information about the event.
-            - **severity**: syslog style from 0 (high) to 7 (low).
-            - **event_filter**: metadata, in Sysdig Monitor format, of nodes to associate with the event, e.g. ``host.hostName = 'ip-10-1-1-1' and container.name = 'foo'``.
-            - **tags**: a list of key-value dictionaries that can be used to tag the event. Can be used for filtering/segmenting purposes in Sysdig Monitor.
-
-        **Success Return Value**
-            A dictionary describing the new event.
-
-        **Examples**
-            - `examples/post_event_simple.py <https://github.com/draios/python-sdc-client/blob/master/examples/post_event_simple.py>`_
-            - `examples/post_event.py <https://github.com/draios/python-sdc-client/blob/master/examples/post_event.py>`_
-        '''
-        options = {
-            'name': name,
-            'description': description,
-            'severity': severity,
-            'filter': event_filter,
-            'tags': tags
-        }
-        edata = {
-            'event': {k: v for k, v in options.items() if v is not None}
-        }
-        res = requests.post(self.url + '/api/events/', headers=self.hdrs, data=json.dumps(edata), verify=self.ssl_verify)
-        return self._request_result(res)
-
-    def get_events(self, name=None, from_ts=None, to_ts=None, tags=None):
-        '''**Description**
-            Returns the list of Sysdig Monitor events.
-
-        **Arguments**
-            - **name**: filter events by name.
-            - **from_ts**: filter events by start time. Timestamp format is in UTC (seconds).
-            - **to_ts**: filter events by end time. Timestamp format is in UTC (seconds).
-            - **tags**: filter events by tags. Can be, for example ``tag1 = 'value1'``.
-
-        **Success Return Value**
-            A dictionary containing the list of events.
-
-        **Example**
-            `examples/list_events.py <https://github.com/draios/python-sdc-client/blob/master/examples/list_events.py>`_
-        '''
-        options = {
-            'name': name,
-            'from': from_ts,
-            'to': to_ts,
-            'tags': tags
-        }
-        params = {k: v for k, v in options.items() if v is not None}
-        res = requests.get(self.url + '/api/events/', headers=self.hdrs, params=params, verify=self.ssl_verify)
-        return self._request_result(res)
-
-    def delete_event(self, event):
-        '''**Description**
-            Deletes an event.
-
-        **Arguments**
-            - **event**: the event object as returned by :func:`~SdcClient.get_events`.
-
-        **Success Return Value**
-            `None`.
-
-        **Example**
-            `examples/delete_event.py <https://github.com/draios/python-sdc-client/blob/master/examples/delete_event.py>`_
-        '''
-        if 'id' not in event:
-            return [False, "Invalid event format"]
-
-        res = requests.delete(self.url + '/api/events/' + str(event['id']), headers=self.hdrs, verify=self.ssl_verify)
-        if not self._checkResponse(res):
-            return [False, self.lasterr]
-        return [True, None]
-
     def get_data(self, metrics, start_ts, end_ts=0, sampling_s=0,
                  filter='', datasource_type='host', paging=None):
         '''**Description**
@@ -480,7 +407,8 @@ class _SdcCommon(object):
         if sampling_s != 0:
             reqbody['sampling'] = sampling_s
 
-        res = requests.post(self.url + '/api/data/', headers=self.hdrs, data=json.dumps(reqbody), verify=self.ssl_verify)
+        res = requests.post(self.url + '/api/data/', headers=self.hdrs, data=json.dumps(reqbody),
+                            verify=self.ssl_verify)
         return self._request_result(res)
 
     def get_sysdig_captures(self, from_sec=None, to_sec=None, scope_filter=None):
@@ -501,8 +429,8 @@ class _SdcCommon(object):
         url = '{url}/api/sysdig?source={source}{frm}{to}{scopeFilter}'.format(
             url=self.url,
             source=self.product,
-            frm="&from=%d" % (from_sec * 10**6) if from_sec else "",
-            to="&to=%d" % (to_sec * 10**6) if to_sec else "",
+            frm="&from=%d" % (from_sec * 10 ** 6) if from_sec else "",
+            to="&to=%d" % (to_sec * 10 ** 6) if to_sec else "",
             scopeFilter="&scopeFilter=%s" % scope_filter if scope_filter else "")
         res = requests.get(url, headers=self.hdrs, verify=self.ssl_verify)
         return self._request_result(res)
@@ -624,7 +552,8 @@ class _SdcCommon(object):
                    'systemRole': system_role}
         user_json = {k: v for k, v in options.items() if v is not None}
 
-        res = requests.post(self.url + '/api/users', headers=self.hdrs, data=json.dumps(user_json), verify=self.ssl_verify)
+        res = requests.post(self.url + '/api/users', headers=self.hdrs, data=json.dumps(user_json),
+                            verify=self.ssl_verify)
         return self._request_result(res)
 
     def delete_user(self, user_email):
@@ -689,7 +618,8 @@ class _SdcCommon(object):
         else:
             reqbody['lastName'] = lastName
 
-        res = requests.put(self.url + '/api/users/' + str(user['id']), headers=self.hdrs, data=json.dumps(reqbody), verify=self.ssl_verify)
+        res = requests.put(self.url + '/api/users/' + str(user['id']), headers=self.hdrs, data=json.dumps(reqbody),
+                           verify=self.ssl_verify)
         if not self._checkResponse(res):
             return [False, self.lasterr]
         return [True, 'Successfully edited user']
@@ -810,7 +740,8 @@ class _SdcCommon(object):
         if filter != '':
             reqbody['filter'] = filter
 
-        res = requests.post(self.url + '/api/teams', headers=self.hdrs, data=json.dumps(reqbody), verify=self.ssl_verify)
+        res = requests.post(self.url + '/api/teams', headers=self.hdrs, data=json.dumps(reqbody),
+                            verify=self.ssl_verify)
         return self._request_result(res)
 
     def edit_team(self, name, memberships=None, filter=None, description=None, show=None, theme=None,
@@ -881,7 +812,8 @@ class _SdcCommon(object):
         elif 'filter' in list(t.keys()):
             reqbody['filter'] = t['filter']
 
-        res = requests.put(self.url + '/api/teams/' + str(t['id']), headers=self.hdrs, data=json.dumps(reqbody), verify=self.ssl_verify)
+        res = requests.put(self.url + '/api/teams/' + str(t['id']), headers=self.hdrs, data=json.dumps(reqbody),
+                           verify=self.ssl_verify)
         return self._request_result(res)
 
     def delete_team(self, name):
@@ -989,6 +921,61 @@ class _SdcCommon(object):
         else:
             return [True, None]
 
+    def list_access_keys(self):
+        '''
+        **Description**
+            List all the access keys enabled and disabled for this instance of Sysdig Monitor/Secure
+
+        **Reslut**
+            A list of access keys objects
+
+        **Example**
+            `examples/list_access_keys.py <https://github.com/draios/python-sdc-client/blob/master/examples/list_access_keys.py>`_
+        '''
+        res = requests.get(self.url + '/api/customer/accessKeys', headers=self.hdrs, verify=self.ssl_verify)
+        return self._request_result(res)
+
+    def create_access_key(self):
+        '''
+        **Description**
+            Create a new access key for Sysdig Monitor/Secure
+
+        **Reslut**
+            The access keys object
+        '''
+        res = requests.post(self.url + '/api/customer/accessKeys', headers=self.hdrs, verify=self.ssl_verify)
+        return self._request_result(res)
+
+    def disable_access_key(self, access_key):
+        '''
+        **Description**
+            Disable an existing access key
+
+        **Arguments**
+            - **access_key**: the access key to be disabled
+
+        **Reslut**
+            The access keys object
+        '''
+        res = requests.post(self.url + '/api/customer/accessKeys/' + access_key + "/disable/", headers=self.hdrs,
+                            verify=self.ssl_verify)
+        return self._request_result(res)
+
+    def enable_access_key(self, access_key):
+        '''
+        **Description**
+            Enable an existing access key
+
+        **Arguments**
+            - **access_key**: the access key to be enabled
+
+        **Reslut**
+            The access keys object
+        '''
+        res = requests.post(self.url + '/api/customer/accessKeys/' + access_key + "/enable/", headers=self.hdrs,
+                            verify=self.ssl_verify)
+        return self._request_result(res)
+
     def get_agents_config(self):
         res = requests.get(self.url + '/api/agents/config', headers=self.hdrs, verify=self.ssl_verify)
         if not self._checkResponse(res):
@@ -997,12 +984,13 @@ class _SdcCommon(object):
         return [True, data]
 
     def set_agents_config(self, config):
-        res = requests.put(self.url + '/api/agents/config', headers=self.hdrs, data=json.dumps(config), verify=self.ssl_verify)
+        res = requests.put(self.url + '/api/agents/config', headers=self.hdrs, data=json.dumps(config),
+                           verify=self.ssl_verify)
         return self._request_result(res)
 
     def clear_agents_config(self):
         data = {'files': []}
-        self.set_agents_config(data)
+        return self.set_agents_config(data)
 
     def get_user_api_token(self, username, teamname):
         res = self.get_team(teamname)
@@ -1011,7 +999,8 @@ class _SdcCommon(object):
 
         t = res[1]
 
-        res = requests.get(self.url + '/api/token/%s/%d' % (username, t['id']), headers=self.hdrs, verify=self.ssl_verify)
+        res = requests.get(self.url + '/api/token/%s/%d' % (username, t['id']), headers=self.hdrs,
+                           verify=self.ssl_verify)
         if not self._checkResponse(res):
             return [False, self.lasterr]
         data = res.json()
